@@ -1,7 +1,4 @@
-# Copyright 2021 Cognite AS
-from enum import Enum
-from typing import Union
-
+# Copyright 2022 Cognite AS
 from indsl import (
     data_quality,
     detect,
