@@ -39,7 +39,7 @@ def rolling_stddev_timedelta(
     return (
         data.index.to_series()
         .diff()
-        .astype("timedelta64[s]")
+        .astype("timedelta64[ms]")
         .fillna(0)
         .rolling(window=time_window, min_periods=min_periods)
         .std()
