@@ -158,13 +158,30 @@ class DataQualityScoreAnalyser(ABC):
             )
         return  # type: ignore
 
-    @staticmethod
-    def _convert_series_to_events(series) -> List[Tuple[pd.Timestamp, pd.Timestamp]]:
+    def _convert_series_to_events(self, series) -> List[Tuple[pd.Timestamp, pd.Timestamp]]:
         # Each gap in the input series is represented as a consecutive (1, 1) pair.
         # Hence filtering the 1 values and re-arranging the associated index as pairs
         # yields a list of the (start, end) gap events.
         events_array = list(series[series == 1].index.values.reshape(-1, 2))
-        return [(pd.Timestamp(start), pd.Timestamp(end)) for start, end in events_array]
+
+        # gaps are merged if the input series has consecutive gaps (see generate_step_series)
+        # to split the gaps again we need to loop though the events and add the original timestamps:
+        # todo: remove this code if generate_step_series handles consecutive gaps without merging
+        timestamps = np.array(self.series.index)
+        events_array_unmerged = []
+
+        for (start, end) in events_array:
+            merged_timestamps = timestamps[(timestamps > start) & (timestamps < end)]
+            if merged_timestamps:
+                events_unmerged = np.concatenate(
+                    (merged_timestamps, merged_timestamps, np.array([start, end])), axis=0
+                )  # duplicate timestamps to create events
+                events_unmerged_sorted = np.sort(events_unmerged)
+                events_array_unmerged.extend(events_unmerged_sorted.reshape(-1, 2))
+            else:
+                events_array_unmerged.append([start, end])
+
+        return [(pd.Timestamp(start), pd.Timestamp(end)) for start, end in events_array_unmerged]
 
     @staticmethod
     def _filter_events_outside_analysis_period(
