@@ -29,7 +29,7 @@ def flow_through_valve(
     type: Literal["Linear", "EQ"] = "Linear",
     align_timestamps: bool = False,
 ) -> pd.Series:
-    r"""Valve volumetric flow rate
+    r"""Valve volumetric flow rate.
 
     This calculation can be used when there is no flow meter, but the pressure difference over the valve is known.
     The calculated flow rate is only exactly applicable for ideal fluids (incompressible and with zero viscosity).
