@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 import operator as op
 
 import numpy as np
@@ -9,18 +9,18 @@ from indsl.type_check import check_types
 
 
 @check_types
-def productivity_index(p_res: pd.Series, p_bh: pd.Series, Q_gas: pd.Series, align_timesteps: bool = False):
+def productivity_index(p_res: pd.Series, p_bh: pd.Series, Q_gas: pd.Series, align_timesteps: bool = False) -> pd.Series:
     """Productivity Index.
 
     The productivity index or PI is defined as the gas flow rate at the well divided by the difference in pressure
-    between the reservoir and bottom hole. If there is no data available for any of the inputs for a specific
+    between the reservoir and bottom hole. If no data is available for any of the inputs for a specific
     timestamp, then it will be ignored.
 
     Args:
         p_res: Reservoir pressure.
         p_bh: Bottomhole pressure.
         Q_gas: Gas flowrate.
-        align_timesteps: Auto-align
+        align_timesteps: Auto-align.
           Automatically align time stamp  of input time series. Default is False.
 
     Returns:
