@@ -1,11 +1,13 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
+from typing import Tuple
+
 import numpy as np
 import pandas as pd
 
+from indsl.exceptions import UserValueError
 from indsl.resample.auto_align import auto_align
 from indsl.type_check import check_types
-
-from ..exceptions import UserRuntimeError
+from indsl.validations import validate_series_is_not_empty
 
 
 CONVERT_R_TO_K = 5 / 9  # conversion from R to K
@@ -43,12 +45,13 @@ def calculate_gas_density(
            Estimated gas density in pound-mass per cubic foot (pcf).
 
     Raises:
-       RuntimeError: When all values of the pressure and temperature are out of range for calculating compressibility.
+       UserValueError: When all values of the pressure and temperature are out of range for calculating compressibility.
     """
     # check specific gravity value
+    validate_series_is_not_empty(sg)
     sg = sg[0]
     if sg == 0:
-        raise RuntimeError("Specific gravity cannot be zero")
+        raise UserValueError("Specific gravity cannot be zero")
 
     # auto-align
     pressure, temperature = auto_align([pressure, temperature], align_timesteps)
@@ -79,9 +82,9 @@ def calculate_gas_density(
         pressure_Kpa.loc[ixs],
     )
     if compressibility.empty or temperature_K.empty:
-        raise RuntimeError("Compressibility or temperature series are empty after filtering zeros")
+        raise UserValueError("Compressibility or temperature series are empty after filtering zeros")
     if R == 0:
-        raise RuntimeError("Gas constant is zero. Division by zero is not allowed")
+        raise UserValueError("Gas constant is zero. Division by zero is not allowed")
 
     # calculate gas density
     rho = pressure_Kpa / R / temperature_K / compressibility
@@ -89,7 +92,8 @@ def calculate_gas_density(
     return rho_out.dropna()
 
 
-def calculate_critical_prop(sg: float):
+@check_types
+def calculate_critical_prop(sg: float) -> Tuple[float, float]:
     """Critical properties.
 
     Returns the crtitcal pressure and temperature as a function of specific gravity (Sutton - 1973).
@@ -111,7 +115,10 @@ def calculate_critical_prop(sg: float):
     return (Pc, Tc)
 
 
-def calculate_reduced_prop(pressure_Kpa: pd.Series, temperature_K: pd.Series, Pc: float, Tc: float):
+@check_types
+def calculate_reduced_prop(
+    pressure_Kpa: pd.Series, temperature_K: pd.Series, Pc: float, Tc: float
+) -> Tuple[pd.Series, pd.Series]:
     """Reduced properties.
 
     Returns the reduced pressure and temperature from input pressure, temperature, and critical prperties.
@@ -138,7 +145,8 @@ def calculate_reduced_prop(pressure_Kpa: pd.Series, temperature_K: pd.Series, Pc
     return (Ppr, Tpr)
 
 
-def calculate_compressibility(Ppr: pd.Series, Tpr: pd.Series):
+@check_types
+def calculate_compressibility(Ppr: pd.Series, Tpr: pd.Series) -> pd.Series:
     """Gas Compressibility.
 
     Returns the compressibility factor from reduced pressure and temperature.
@@ -155,7 +163,7 @@ def calculate_compressibility(Ppr: pd.Series, Tpr: pd.Series):
             Non-dimensional series.
 
     Raises:
-       UserRuntimeError: When all values of the pressure and temperature are out of range for calculating compressibility.
+       UserValueError: When all values of the pressure and temperature are out of range for calculating compressibility.
     """
     # delete points that are out of range, raise error if empty
     Tpr = Tpr[(Tpr.values >= 1) & (Tpr.values <= 3)]
@@ -164,7 +172,7 @@ def calculate_compressibility(Ppr: pd.Series, Tpr: pd.Series):
     Tpr, Ppr = Tpr.loc[idx], Ppr.loc[idx]
 
     if Tpr.empty or Ppr.empty:
-        raise UserRuntimeError("Pressure and Temperature data are empty or out of range")
+        raise UserValueError("Pressure and Temperature data are empty or out of range")
 
     A = 1.39 * (Tpr - 0.92) ** 0.5 - 0.36 * Tpr - 0.10
     E = 9 * (Tpr - 1)
