@@ -3,12 +3,16 @@ import os
 
 from typing import Literal
 
+import numpy as np
 import pandas as pd
 
 from scipy import interpolate as intp
 
+from indsl.type_check import check_types
 
-def _error_handling(pvt_table, pressure, temperature):
+
+@check_types
+def _error_handling(pvt_table: np.ndarray, pressure: pd.Series, temperature: pd.Series) -> None:
     max_pressure, min_pressure = max(pvt_table[:, [0]])[0], min(pvt_table[:, [0]])[0]
     max_temperature, min_temperature = max(pvt_table[:, [1]])[0], min(pvt_table[:, [1]])[0]
 
@@ -35,6 +39,7 @@ def _error_handling(pvt_table, pressure, temperature):
         raise Exception(msg)
 
 
+@check_types
 def retrieve_fluid_properties(
     pressure: pd.Series,
     temperature: pd.Series,
@@ -44,15 +49,15 @@ def retrieve_fluid_properties(
 ) -> pd.Series:
     """Retrieve fluid properties.
 
-    Function to obtain value for selected fluid property (`param`) corresponding to the pressure/temp pairs input as series. The input fluid file type is a .tab file that is an output
-    of an equation of state simulator (i.e PVTSim, MultiFlash) and is an input file specifically for OLGA. There are 31 fluid property parameters included in the .tab file which are the
-    options as an output for this function. Note that pressure and temperature sensors have to come from the same location.
+    This function obtains the value for the selected fluid property (`param`) corresponding to the pressure/temp pairs input as series. The input fluid file type is a .tab file that is an output
+    of an equation of state simulator (i.e PVTSim, MultiFlash) and is an input file specifically for OLGA. The 31 fluid property parameters included in the .tab file are the options as an output for this function.
+    Note that pressure and temperature sensors have to come from the same location.
 
     Args:
         pressure: Pressure time series.
         temperature: Temperature time series.
         pvt_data: PVT data.
-            This is a PVT table that has been parse out from a .tab file which is a standardized generated output of
+            This is a PVT table that has been parsed out from a .tab file which is a standardized generated output of
             MultiFlash and PVTSim.
         param: Fluid parameter of interest.
             Fluid property to be estimated.
