@@ -1,18 +1,21 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 from numbers import Number
-from typing import Iterable, List, Union
+from typing import Any, Iterable, List, Union
 
 import numpy as np
 import pandas as pd
 
+from indsl.type_check import check_types
+
 from .reindex import reindex_many
 
 
-def _is_timeseries(data):
+def _is_timeseries(data: Any) -> bool:
     return isinstance(data, pd.Series) and np.issubdtype(data.index, np.datetime64)
 
 
-def auto_reindex(data: List[Union[Iterable, Number, pd.Series]], enabled: bool = True):
+@check_types
+def auto_reindex(data: List[Union[Iterable, Number, pd.Series]], enabled: bool = True) -> list:
     """Automatically re-reindex input time series."""
     if not enabled:
         return data
@@ -26,10 +29,10 @@ def auto_reindex(data: List[Union[Iterable, Number, pd.Series]], enabled: bool =
     out = data.copy()
     for idx, ts in zip(id_ts_map.keys(), reindexed_ts):
         out[idx] = ts
-
     return out
 
 
-def auto_align(data: List[Union[Iterable, Number, pd.Series]], enabled: bool = True):
+@check_types
+def auto_align(data: List[Union[Iterable, Number, pd.Series]], enabled: bool = True) -> list:
     """Automatically re-reindex input time series."""
     return auto_reindex(data, enabled=enabled)
