@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 import pandas as pd
 
 from scipy.signal import cheby1, cheby2, sosfilt
@@ -18,7 +18,7 @@ def chebyshev(
     rp: float = 0.1,
     Wn: float = 0.1,
     btype: str = "lowpass",
-):
+) -> pd.Series:
     """Chebyshev (I, II).
 
     Chebyshev filters are analog or digital filters having a steeper roll-off than Butterworth filters, and have
@@ -38,7 +38,7 @@ def chebyshev(
         Wn: Critical frequency.
             Number between 0 and 1, with 1 representing one-half of the sampling rate (Nyquist frequency).
             Defaults to 0.1.
-        btype: Filter type
+        btype: Filter type.
             The options are: "lowpass" and "highpass"
             Defaults to "lowpass".
 
@@ -52,6 +52,9 @@ def chebyshev(
     if filter_type not in {1, 2}:
         raise UserValueError("Filter type must be either 1 or 2.")
 
+    if len(data) < 1:
+        return data
+
     # Get type 1 and 2 chebyshev filter
     cheby_filters = {1: cheby1, 2: cheby2}
 
